@@ -2,7 +2,7 @@ class FakeUserSettings:
     def __init__(self, filepath="test/directory/", dotSize=2, blobSize=5, saveFigures=False, 
         startImage="", skipsAllowed=0, removeEdgeFrames=True, thresholds=(1.5, 5.0, 2.0), 
         lowerContrast=0.0, upperContrast=5.0, lowerDotThresh=1.5, upperDotThresh=5.0, 
-        lowerBlobThresh=2.0):
+        lowerBlobThresh=2.0, program="density"):
         self.filepath = filepath
         self.dotSize = dotSize
         self.blobSize = blobSize
@@ -15,4 +15,5 @@ class FakeUserSettings:
         self.upperContrast = upperContrast
         self.lowerDotThresh = lowerDotThresh
         self.upperDotThresh = upperDotThresh
-        self.lowerBlobThresh = lowerBlobThresh
\ No newline at end of file
+        self.lowerBlobThresh = lowerBlobThresh
+        self.program = program
\ No newline at end of file
